%I generally like to start any script by clearing all current variables and
%closing all plots and files and interfaces - i.e. just starting with a 
%clean slate:
clear all
clear global
close all
clc

%we also need to add the directory for the helper functions so Matlab 
%knows where to find them(this could be anywhere you want but is usually in
%a subdirectory of this demo code. You only actually need to do this once
%per computer but it doesn harm to leave it in either.
addpath('./HelperFunctions')


%Open an interface to Xtralien using the OpenCLOI command.
%All we need to know is the COM port number (in this case COM3 but you can
%identify it by using Device Manager on Windows.
%The OpenCLOI function returns an instrument identifier which in this case
%we'll call Xtralien1 (if we had another instrument connected at the same
%time we could call that Xtralien2).
Xtralien1=OpenCLOI('COM3');

%first of all let specify what measurement range we're using.
%Range 	Max Current 	Accuracy
%1      100 mA          10 A
%2      10 mA           1 A
%3      1 mA            100 nA
%4      100 A          10 nA
%5      10 A           1 nA
%IMPORTANT NOTE:
%The range on the Xtralien needs to be set in hardware as well as software
%by using the small switches (see website or user manual).
SetRange(Xtralien1,'SMU1', 1) %Here we'll use range 1 on SMU1

%We also want to specify the measurement speed (slower=more accurate).
%You can specify an OSR rate from 1 (fastest) to 9 (slowest)
SetOSR(Xtralien1,'SMU1', 5);

%Now lets set the voltage on SMU1 to 1 volt and measure the current
%We do this by calling the SMU1 command which needs to know which
%instrument it is talking to (in this case Xtralien1m and what voltage to
%set (in this case 1 volt). 
[V,I]=SMU1(Xtralien1,1)
%After it has set the voltage on SMU1, it returns the measured voltage as V
%and the measured current as I. Note that in most cases the set voltage and
%the measured voltage should be the same. However, in some cases (such as
%if the device you're trying to measure is short circuited) there could be 
%a difference.

%Now that we've finished our measurement we can close the interface. 
CloseCLOI(Xtralien1);

%That's it. Our first measurement taken.
