%Open a CLOI interface to the Xtralien board using COM and call it Xtralien1
Xtralien1=OpenCLOI('COM3');

%first of all let specify what measurement range we're using.
%Range 	Max Current 	Accuracy
%1      100 mA          10 A
%2      10 mA           1 A
%3      1 mA            100 nA
%4      100 A          10 nA
%5      10 A           1 nA
%IMPORTANT NOTE:
%The range on the Xtralien needs to be set in hardware as well as software
%by using the small switches (see website or user manual).
SetRange(Xtralien1,'SMU1', 1) %Here we'll use range 1 on SMU1

%We also want to specify the measurement speed (slower=more accurate).
%You can specify an OSR rate from 1 (fastest) to 9 (slowest)
SetOSR(Xtralien1,'SMU1', 5);

%Now lets loop through some voltages. Here we're going to use the matlab
%syntax start:step:stop to create a sweep from -1 Volts to +1 volts in 0.1
%volt (100 mV) steps.
for set_voltage=-1:0.1:1
    %for each voltage that we loop through we'll use the SMU1 command to
    %apply the desired set_voltage and then measure the actual voltage (V) 
    %and current (I).
    [V,I]=SMU1(Xtralien1,set_voltage);
    %Now lets plot the data points so we can see what's happening. Note
    %that we put the hold on so that we don't lose one data point when we
    %plot the next.
    plot(V,I,'X'); hold on;
    %We can also display th data in the main matlab command widow if we want.
    disp([V,I]);
end
    
%Now that we've finished our measurement we can close the interface.
%However, before we do it's always good practice to set the voltages back
%to zero again.
[V,I]=SMU1(Xtralien1,0); %set the voltage back to zero
CloseCLOI(Xtralien1); %and close the interface
