%Open a CLOI interface to the Xtralien board using COM14 and call it Xtralien1
Xtralien1=OpenCLOI('COM3');

%first of all let specify what measurement range we're using.
%Range 	Max Current 	Accuracy
%1      100 mA          10 A
%2      10 mA           1 A
%3      1 mA            100 nA
%4      100 A          10 nA
%5      10 A           1 nA
%IMPORTANT NOTE:
%The range on the Xtralien needs to be set in hardware as well as software
%by using the small switches (see website or user manual).
SetRange(Xtralien1,'SMU1', 1) %Here we'll use range 1 on SMU1
SetRange(Xtralien1,'SMU2', 5) %Here we'll use range 5 on SMU2


%We also want to specify the measurement speed (slower=more accurate).
%You can specify an OSR rate from 1 (fastest) to 9 (slowest)
SetOSR(Xtralien1,'SMU1', 5);
SetOSR(Xtralien1,'SMU2', 5);

%Usually when measuring an OLED there's a small amount of background light
%around and so before we measure the light output from our OLED we can
%measure this background light. We use the SMU2 command to measure the
%photocurrent from the photodiode with zero volts applied.
[V2,I2]=SMU2(Xtralien1,0);
%and store the background current as an Offset
SMU2_offset=I2;

%Now that we've measured the background light we can loop through the
%voltages we want to measure. Note that we aren't using the in-built sweep
%function as we want to co-ordinate two different SMUs at the same time
%In this case let's loop from zero to three volts in 0.1 volt steps
for set_voltage=0:0.1:3
    %each time we loop set the relevant voltage on SMU1 which is actually
    %driving the LED
    [V1,I1]=SMU1(Xtralien1,set_voltage);
    %and measure the photocurrent detected by the photodiode (with no 
    %voltage applied) which is connected to SMU2
    [V2,I2]=SMU2(Xtralien1,0);
    %Substract the background photocurrent (measured earlier) from SMU2
    I2= I2 - SMU2_offset;
    %and then plot the three paramaters of interest on three different axes
    %of the same figure using subplot.
    subplot(3,1,1); %select the first graph
    %and plot the drive current versus the applied voltage
    plot(V1,I1,'x'); hold on; ylabel('Drive Current (A)');
    subplot(3,1,2); %select the second plot
    %and plot the photocurrent versus the applied voltage
    plot(V1,I2,'x'); hold on; ylabel('Photocurrent (A)'); 
    subplot(3,1,3); %select the third plot
    %and plot the efficacy versus the applied voltage
    %note that the efficacy is just the photocurrent divided by the drive
    %current and is in arbitrary unit.
    plot(V1,I2/I1,'x'); hold on; ylabel('Efficacy (Arbitrary)'); 
    %and finally add the x-axis which is common to all three
    xlabel('Drive Voltage (V)');
end

%Now that we've finished our measurement we can close the interface.
%As usual lets set the voltages back to zero again first though.
[V,I]=SMU1(Xtralien1,0); %set the voltage back to zero
CloseCLOI(Xtralien1); %and close the interface